==> kdelibs-3.0.1.tar.bz2: kdelibs-3.0.1/kdeprint/kfilelist.h <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 **/

#ifndef KFILELIST_H
#define KFILELIST_H

#include <qwidget.h>
#include <qptrlist.h>

class KListView;
class QPushButton;
class QListViewItem;

class KFileList : public QWidget
{
	Q_OBJECT
public:
	KFileList(QWidget *parent = 0, const char *name = 0);
	virtual ~KFileList();

	void setFileList(const QStringList&);
	QStringList fileList() const;
	QSize sizeHint() const;

protected slots:
	void slotAddFile();
	void slotRemoveFile();
	void slotOpenFile();
	void slotSelectionChanged();

protected:
	void dragEnterEvent(QDragEnterEvent*);
	void dropEvent(QDropEvent*);
	void addFiles(const QStringList&);
	void selection(QPtrList<QListViewItem>&);

private:
	KListView	*m_files;
	QPushButton	*m_add, *m_remove, *m_open;
	bool		m_block;
};

#endif

==> kdelibs-3.1.tar.bz2: kdelibs-3.1/kdeprint/kfilelist.h <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 **/

#ifndef KFILELIST_H
#define KFILELIST_H

#include <qwidget.h>
#include <qptrlist.h>

class KListView;
class QPushButton;
class QListViewItem;

class KFileList : public QWidget
{
	Q_OBJECT
public:
	KFileList(QWidget *parent = 0, const char *name = 0);
	virtual ~KFileList();

	void setFileList(const QStringList&);
	QStringList fileList() const;
	QSize sizeHint() const;

protected slots:
	void slotAddFile();
	void slotRemoveFile();
	void slotOpenFile();
	void slotSelectionChanged();
	void slotUp();
	void slotDown();

protected:
	void dragEnterEvent(QDragEnterEvent*);
	void dropEvent(QDropEvent*);
	void addFiles(const QStringList&);
	void selection(QPtrList<QListViewItem>&);

private:
	KListView	*m_files;
	QPushButton	*m_add, *m_remove, *m_open, *m_up, *m_down;
	bool		m_block;
};

#endif
